/*
Replication Code for Article:
From "Different" to "Similar": An Experimental Approach to Understanding Assimilation
Forthcoming in the American Sociological Review
Year of Publication: 2016
Author: Ariela Schachter
contact: ariela@wustl.edu


Code last updated: 6/22/2016

Please contact Ariela Schachter with any questions/comments and to report any bugs in the code.
*/

/* Note: this do-file uses the following ado files: coefplot, mdesc, outreg2, and
grc1leg. You will need to install them prior to running the do-file. */

/* Set your local file path here */
clear
use Schachter_2016_Public.dta

/* Generate Respondent characteristic moderators using merged contextual data 
from 2009-2013 ACS (already merged into public dataset) */
gen morewhite=.
replace morewhite=1 if whitepct>=74&whitepct<.
replace morewhite=0 if whitepct<74

gen old_age=.
replace old_age=1 if age>=50&age<.
replace old_age=0 if age<50

gen morefb=.
replace morefb=1 if fbpct>=10&fbpct<.
replace morefb=0 if fbpct<10

**rescale dvs to run 0-1**
foreach var of varlist similar_a similar_b {
gen `var'_a = `var'/7
rename `var' `var'_orig
rename `var'_a `var'
}

foreach var of varlist common_a common_b {
gen `var'_a = `var'/5
rename `var' `var'_orig
rename `var'_a `var'
}

foreach var of varlist friend_a friend_b {
gen `var'_a = `var'/5
rename `var' `var'_orig
rename `var'_a `var'
}


/* Sample restriction for all analyses: NB White R only */
keep if resp_race==1&nb==1

/*Table 2: Average Marginal Component Effects on Preferred Neighbor and Similarity,
Coefficients and SEs */
set more off
reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table2.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) replace word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table2.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg neighborpair ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table2.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table2.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word

/*Table 3: Average Marginal Component Effects on Standardized Dependent Variables,
Coefficients and SEs */

/*Gen standardized dvs*/
*********************************************************************
egen std_neighbor=std(neighborpair)
egen std_friend=std(friend_a_)
egen std_similar=std(similar_a_)
egen std_common=std(common_a_)
*********************************************************************
/*Gen table */
set more off
reg std_neighbor ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table3.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) replace word
reg std_friend ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table3.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg std_similar ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table3.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg std_common ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using table3.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word


/*Table 4: Changes in Similarity Gaps with Positive Attributes and (Wald Test
Chi-Squares) */

/*Step 1: drop negative attributes for non-Whites and non-USborn Whites */
*Work*
gen racecit_ses=racecitizenshipa
replace racecit_ses =. if workhist_a==0&racet_a>1
replace racecit_ses =. if workhist_a==0&racet_a==1&citizen_a>1
# delimit ;
lab def racecit_ses_lbl 1"U.S.-born" 2"Naturalized" 3"Legal Immigrant" 
4"Undocumented" 5"U.S.-born" 6"Naturalized" 7"Legal Immigrant" 
8"Undocumented" 9"U.S.-born" 10"Naturalized" 11"Legal Immigrant"
12"Undocumented" 13"U.S.-born" 14"Naturalized" 15"Legal Immigrant"
16"Undocumented" ;
# delimit cr
lab val racecit_ses racecit_ses_lbl
*Identity*
gen racecit_ident=racecitizenshipa
replace racecit_ident =. if identity_a==0&racet_a>1
replace racecit_ident =. if identity_a==0&racet_a==1&citizen_a>1
lab val racecit_ident racecit_ses_lbl
*Language*
gen racecit_lang=racecitizenshipa
replace racecit_lang =. if language_a<3&racet_a>1
replace racecit_lang =. if language_a<3&racet_a==1&citizen_a>1
lab val racecit_lang racecit_ses_lbl
*Volunteer*
gen racecit_vol=racecitizenshipa
replace racecit_vol =. if volunteer_a==0&racet_a>1
replace racecit_vol =. if volunteer_a==0&racet_a==1&citizen_a>1
lab val racecit_vol racecit_ses_lbl
*Spouse*
gen racecit_spouse=racecitizenshipa
replace racecit_spouse =. if maritalstat_a==0&racet_a>1
replace racecit_spouse =. if maritalstat_a==0&racet_a==1&citizen_a>1
lab val racecit_spouse racecit_ses_lbl
*Neighborhood*
gen racecit_neigh=racecitizenshipa
replace racecit_neigh =. if neighborhood_a_<3&racet_a>1
replace racecit_neigh =. if neighborhood_a_<3&racet_a==1&citizen_a>1
lab val racecit_neigh racecit_ses_lbl

/*Step 2: Calculate Differences in Similarity Gaps Compared to Baseline and
Conduct Chi-Square Tests Comparing Predicted Similarity Gaps with and
without Attribute Restrictions */
set more off
reg similar_a_ ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a
estimates store similar
reg similar_a_ ib1.racecit_ident ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a
estimates store similar1
reg similar_a_ ib1.racecit_lang ib0.identity_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a
estimates store similar2
reg similar_a_ ib1.racecit_spouse ib0.identity_a ib1.language_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a
estimates store similar3
reg similar_a_ ib1.racecit_neigh ib0.identity_a ib1.language_a ib0.maritalstat_a ib0.volunteer_a ib0.workhist_a
estimates store similar4
reg similar_a_ ib1.racecit_vol ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.workhist_a
estimates store similar5
reg similar_a_ ib1.racecit_ses ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a
estimates store similar6
suest similar similar1 similar2 similar3 similar4 similar5 similar6, vce(cluster respid)
/* Above code saves the predicted similarity gaps with and without all of the restrictions */

/* Below code reports the changes in similarity gaps and the chi-square test statistic 
and p-value for each comparison reported in Table 4 */

**Identity Effects**
forvalues i=2(1)16 {
/*Change in Similarity Gap*/
di abs([similar_mean]`i'.racecitizenshipa) - abs([similar1_mean]`i'.racecit_ident)
/*Wald Test Chi Square*/
test [similar_mean]`i'.racecitizenshipa=[similar1_mean]`i'.racecit_ident
}

**Language**
forvalues i=2(1)16 {
/*Change in Similarity Gap*/
di abs([similar_mean]`i'.racecitizenshipa) - abs([similar2_mean]`i'.racecit_lang)
/*Wald Test Chi Square*/
test [similar_mean]`i'.racecitizenshipa=[similar2_mean]`i'.racecit_lang
}

**Spouse Race**
forvalues i=2(1)16 {
/*Change in Similarity Gap*/
di abs([similar_mean]`i'.racecitizenshipa) - abs([similar3_mean]`i'.racecit_spouse)
/*Wald Test Chi Square*/
test [similar_mean]`i'.racecitizenshipa=[similar3_mean]`i'.racecit_spouse
}

**Neighborhood Race**
forvalues i=2(1)16 {
/*Change in Similarity Gap*/
di abs([similar_mean]`i'.racecitizenshipa) - abs([similar4_mean]`i'.racecit_neigh)
/*Wald Test Chi Square*/
test [similar_mean]`i'.racecitizenshipa=[similar4_mean]`i'.racecit_neigh
}

**Volunteerism**
forvalues i=2(1)16 {
/*Change in Similarity Gap*/
di abs([similar_mean]`i'.racecitizenshipa) - abs([similar5_mean]`i'.racecit_vol)
/*Wald Test Chi Square*/
test [similar_mean]`i'.racecitizenshipa=[similar5_mean]`i'.racecit_vol
}

**Work History**
forvalues i=2(1)16 {
/*Change in Similarity Gap*/
di abs([similar_mean]`i'.racecitizenshipa) - abs([similar6_mean]`i'.racecit_ses)
/*Wald Test Chi Square*/
test [similar_mean]`i'.racecitizenshipa=[similar6_mean]`i'.racecit_ses
}

/* FIGURES */
**Figure 1: Predicted Rates of Neighbor Selection by Race and Citizenship Treatments
**Based on Model 2a, Table 2.
quietly reg neighborpair ib1.racet_a##ib1.citizen_a ib0.identity_a ib3.language_a ///
 ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
quietly margins racet_a, over(citizen_a)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
plot3opts(msymbol(Th) mcolor(blue)) ///
plot4opts(msymbol(Dh) mcolor(orange)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
ci3opts(lcolor(blue)) ///
ci4opts(lcolor(orange)) ///
scheme(lean1) ytitle("Pr(Preferred Neighbor)") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Citizenship Treatment}", span)) ///
ylabel(.1(.1)1)  yline(.5, lpattern(dash))
graph save figure1.gph, replace
graph export figure1.tif, width(3900) replace
graph export figure1.pdf, replace
graph export figure1.eps, preview(on) replace

**Figure 2: Predicted Similarity Ratings by Race and Citizenship Treatments
**Based on Model 2b, Table 2.
quietly reg similar_a_ ib1.racet_a##ib1.citizen_a ib0.identity_a ib3.language_a ///
 ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
quietly margins racet_a, over(citizen_a)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
plot3opts(msymbol(Th) mcolor(blue)) ///
plot4opts(msymbol(Dh) mcolor(orange)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
ci3opts(lcolor(blue)) ///
ci4opts(lcolor(orange)) ///
scheme(lean1) ytitle("Predicted Similarity Score") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Citizenship Treatment}", span)) ///
ylabel(.3(.1).8)   
graph save figure2.gph, replace
graph export figure2.tif, width(3900) replace
graph export figure2.pdf, replace
graph export figure2.eps, preview(on) replace

**Figure 3: Distributions of Similarity and Commonality Scores by Neighbor Preference
label def neighborpair_lbla 0"Not Selected Neighbor" 1"Selected Neighbor"
lab val neighborpair neighborpair_lbla

label def friendship_lbla 1"Uninterested" 2"Somewhat uninterested" 3"Neither interested nor uninterested" 4"Somewhat interested" 5"Interested"
lab val friend_a_ friendship_lbla
lab val friend_b_ friendship_lbla

hist similar_a__orig, percent discrete by(neighborpair, note("")) scheme(lean1) ///
 xlabel(1 2 3 4 5 6 7, valuelabel labsize(small) angle(45)) ///
 xtitle("Similarity Score")
 graph save sim_neigh_hist.gph, replace

hist common_a__orig, percent discrete by(neighborpair, note("")) scheme(lean1) ///
 xlabel(1 2 3 4 5, valuelabel labsize(small) angle(45)) ylabel(0(10)50) ///
 xtitle("Commonality Score")
 graph save com_neigh_hist.gph, replace
 
graph combine sim_neigh_hist.gph com_neigh_hist.gph, ycommon scheme(lean1)
graph save sim_com_neigh_hist.gph, replace
graph export figure3.tif, width(3900) replace
graph export figure3.pdf, replace
graph export figure3.eps, preview(on) replace

**Figure 4: Distribution of Similarity Score by Interest in Friendship
gen friend_cat_a=.
replace friend_cat_a=1 if friend_a__orig==1|friend_a__orig==2
replace friend_cat_a=2 if friend_a__orig==3
replace friend_cat_a=3 if friend_a__orig==4|friend_a__orig==5
lab def friend_cat_lbl 1"Uninterested" 2"Neutral" 3"Interested"
lab val friend_cat_a friend_cat_lbl

hist similar_a__orig, percent discrete by(friend_cat_a, col(3) note("")) scheme(lean1) ///
 xlabel(1 2 3 4 5 6 7, valuelabel labsize(vsmall) angle(45)) ///
 xtitle("Similarity Score")
 graph save sim_friend_hist.gph, replace
graph export figure4.tif, width(3900) replace
graph export figure4.pdf, replace
graph export figure4.eps, preview(on) replace

/*Reported means in text */
mean similar_a__orig, over(neighborpair)
ttest similar_a__orig, by(neighborpair)

mean common_a__orig, over(neighborpair)
ttest common_a__orig, by(neighborpair)

mean similar_a__orig, over(friend_cat_a)
mlogit friend_cat_a similar_a__orig, b(2)

/* Appendix Tables and Figures */

**Appendix Table S1: Sample Descriptives**
set more off
sum age if task==1&ab==1, detail
sum conservative if task==1&ab==1, detail
mdesc age conservative
tab female if task==1&ab==1,m
tab colgrad if task==1&ab==1,m
tab employ if task==1&ab==1,m
tab ownhome if task==1&ab==1, m
tab pid3 if task==1&ab==1, m
tab newsint if task==1&ab==1, m

**Appendix Table S2: Testing for Profile Order Effects: F-tests for Joint Significance
set more off
quietly reg neighborpair ib1.racet_a##ib1.profile ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm racet_a#profile
quietly reg similar_a_ ib1.racet_a##ib1.profile ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm racet_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm citizen_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm citizen_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a##ib1.profile ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm identity_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a##ib1.profile ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm identity_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a##ib1.profile ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm language_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a##ib1.profile ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm language_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a##ib1.profile ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm maritalstat_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a##ib1.profile ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm maritalstat_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a##ib1.profile ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm neighborhood_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a##ib1.profile ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm neighborhood_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a##ib1.profile ib0.workhist_a, vce(cluster respid)
testparm volunteer_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a##ib1.profile ib0.workhist_a, vce(cluster respid)
testparm volunteer_a#profile
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a##ib1.profile, vce(cluster respid)
testparm workhist_a#profile
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a##ib1.profile, vce(cluster respid)
testparm workhist_a#profile

**Appendix Figure S1 **
set more off
quietly reg neighborpair ib1.language_a if profile==1, vce(cluster respid)
estimates store A
quietly reg neighborpair ib1.language_a if profile==2, vce(cluster respid)
estimates store B
quietly reg neighborpair  ib1.language_a  if profile==3, vce(cluster respid)
estimates store C
quietly reg neighborpair  ib1.language_a  if profile==4, vce(cluster respid)
estimates store D
quietly reg neighborpair  ib1.language_a  if profile==5, vce(cluster respid)
estimates store E
quietly reg neighborpair  ib1.language_a  if profile==6, vce(cluster respid)
estimates store F
 
label def lang_short 1"Limited" 2"Accent" 3"Fluent"
lab val language_a lang_short
coefplot A, drop(_cons) baselevels xline(0) grid(none) yscale(noreverse) ///
ylabel(,labsize(medium)) msize(small) scheme(lean2) mcolor(red) ///
xtitle("Effect on Pr(Preferred Neighbor)") ///
title ("Profile 1", span)
graph save p1.gph, replace

coefplot B, drop(_cons) baselevels xline(0) grid(none) yscale(noreverse) ///
ylabel(,labsize(medium)) msize(small) scheme(lean2) mcolor(red) ///
xtitle("Effect on Pr(Preferred Neighbor)") ///
title ("Profile 2", span)
graph save p2.gph, replace

coefplot C, drop(_cons) baselevels xline(0) grid(none) yscale(noreverse) ///
ylabel(,labsize(medium)) msize(small) scheme(lean2) mcolor(red) ///
xtitle("Effect on Pr(Preferred Neighbor)") ///
title ("Profile 3", span)
graph save p3.gph, replace

coefplot D, drop(_cons) baselevels xline(0) grid(none) yscale(noreverse) ///
ylabel(,labsize(medium)) msize(small) scheme(lean2) mcolor(red) ///
xtitle("Effect on Pr(Preferred Neighbor)") ///
title ("Profile 4", span)
graph save p4.gph, replace

coefplot E, drop(_cons) baselevels xline(0) grid(none) yscale(noreverse) ///
ylabel(,labsize(medium)) msize(small) scheme(lean2) mcolor(red) ///
xtitle("Effect on Pr(Preferred Neighbor)") ///
title ("Profile 5", span)
graph save p5.gph, replace

coefplot F, drop(_cons) baselevels xline(0) grid(none) yscale(noreverse) ///
ylabel(,labsize(medium)) msize(small) scheme(lean2) mcolor(red) ///
xtitle("Effect on Pr(Preferred Neighbor)") ///
title ("Profile 6", span)
graph save p6.gph, replace

graph combine p1.gph p2.gph p3.gph p4.gph p5.gph p6.gph, altshrink scheme(lean1) xcommon
graph save figures1.gph, replace
graph export figures1.eps, as(eps) preview(on) replace


**Appendix Table S3: Testing for Row Order Effects: F-tests for Joint Significance
quietly reg neighborpair ib1.racet_a##ib1.race_order ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm racet_a#race_order
quietly reg similar_a_ ib1.racet_a##ib1.race_order ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm racet_a#race_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a##ib1.citizen_order ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm citizen_a#citizen_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.citizen_order ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm citizen_a#citizen_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a##ib1.ident_order ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm identity_a#ident_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a##ib1.ident_order ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm identity_a#ident_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a##ib1.lang_order ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm language_a#lang_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a##ib1. lang_order ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm language_a#lang_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a##ib1.spouse_order ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm maritalstat_a#spouse_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a##ib1.spouse_order ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm maritalstat_a#spouse_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a##ib1.neighborhood_order ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm neighborhood_a#neighborhood_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a##ib1.neighborhood_order ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
testparm neighborhood_a#neighborhood_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a##ib1.volunteer_order ib0.workhist_a, vce(cluster respid)
testparm volunteer_a#volunteer_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a##ib1.volunteer_order ib0.workhist_a, vce(cluster respid)
testparm volunteer_a#volunteer_order
quietly reg neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a##ib1.work_order, vce(cluster respid)
testparm workhist_a#work_order
quietly reg similar_a_ ib1.racet_a ib1.citizen_a##ib1.profile ib0.identity_a ib3.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a##ib1.work_order, vce(cluster respid)
testparm workhist_a#work_order

**Appendix Table S4. Alternative Model Specifications, Log-Odds and (Standard Errors)***
**Dichotomizing Similarity, Commonality, and Friendship, estimate w/ logit model****
**create variable that separates out "cases" by respid*task*
egen clogit_id =group(respid task)

gen similar_d=0
replace similar_d=1 if similar_a__orig>=5

gen common_d=0
replace common_d=1 if common_a__orig>=4
replace common_d=. if common_a__orig==.

gen friend_d=0
replace friend_d=1 if friend_a__orig>=4
replace friend_d=. if friend_a__orig==.

set more off
logit neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using appendix_tables4.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) addstat(Pseudo R-squared, `e(r2_p)') replace word
clogit neighborpair ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, group(clogit_id)
outreg2 using appendix_tables4.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) addstat(Pseudo R-squared, `e(r2_p)') append word
logit friend_d ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using appendix_tables4.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) addstat(Pseudo R-squared, `e(r2_p)') append word
logit similar_d ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using appendix_tables4.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) addstat(Pseudo R-squared, `e(r2_p)') append word
logit common_d ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
outreg2 using appendix_tables4.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) addstat(Pseudo R-squared, `e(r2_p)') append word

**Appendix Table S5: Simulations of Latino Neighbor Preference Rate by Citizenship Status
/*Predicted Preference Rate */
quietly reg neighborpair ib1.racecitizenshipa ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racecitizenshipa
**Latinos are rows 9-12**

/*Original values*/
/*Latino Preference Rate*/
di (.59*.25)+(.59*.25)+(.51*.25)+(.29*.25)
/*Disadvantage Relative to Whites*/
di (.5457759+.6191349 +.5506625 +.3261618 )/4
di .5104-.495

/*Common Stereotyping*/
/*Latino Preference Rate*/
di (.5*.59) +(.5*.29)
/*Disadvantage Relative to Whites*/
di .5104-.44

/*Extreme Stereotyping*/
/*Latino Preference Rate*/
di 1*.29
/*Disadvantage Relative to Whites*/
di .5104-.29

**Appendix Table S6: Pair-wise Correlations of Dependent Variables**
pwcorr neighborpair friend_a_ similar_a_ common_a_

**Appendix Table S7: Similarity Treatment Effects by Respondent Characteristics, Coefficients and (SEs)
set more off
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if old_age==1, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) replace word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if old_age==0, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if morewhite==1, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if morewhite==0, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if repub==1, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if repub==0, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if colgrad==0, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word
reg similar_a_ ib1.racet_a ib1.citizen_a ib0.identity_a ib1.language_a ib0.maritalstat_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a if colgrad==1, vce(cluster respid)
outreg2 using appendix_tables7.doc, stats (coef se) paren(se) dec(3) symbol(***,**,*,+) alpha(0.001, 0.01, 0.05, 0.10) append word

**Appendix Figure S2. Identity-Race Interactions on Neighbor and Similarity**
quietly reg neighborpair ib1.racet_a##ib0.identity_a ib1.neighborhood_a ib1.citizen_a  ib1.language_a i.maritalstat_a_  ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racet_a, over(identity_a)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
scheme(lean1) ytitle("Pr(Preferred Neighbor)") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Background}", span)) ///
ylabel(.3(.05).7) yline(.5, lpattern(dash))
graph save race_ident_reg_N.gph, replace

quietly reg similar_a_ ib1.racet_a##ib0.identity_a ib1.neighborhood_a ib1.citizen_a  ib1.language_a i.maritalstat_a_  ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racet_a, over(identity_a)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
scheme(lean1) ytitle("Predicted Similarity Score") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Background}", span)) ///
ylabel(.3(.05).7)
graph save race_ident_reg_S.gph, replace

grc1leg race_ident_reg_N.gph race_ident_reg_S.gph, altshrink scheme(lean1)
graph export figures2.eps, as(eps) preview(on) replace

**Appendix Figure S3. Spouse Race-Race Interactions on Neighbor and Similarity**
quietly reg neighborpair ib1.racet_a##i.maritalstat_a_ ib1.citizen_a ib0.identity_a ib1.language_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racet_a, over(maritalstat_a_)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
scheme(lean1) ytitle("Pr(Preferred Neighbor)") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Spouse Race}", span)) ///
ylabel(.3(.05).7) yline(.5, lpattern(dash))
graph save race_spouse_reg_N.gph, replace

quietly reg similar_a_ ib1.racet_a##i.maritalstat_a_ ib1.citizen_a ib0.identity_a ib1.language_a ib1.neighborhood_a ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racet_a, over(maritalstat_a_)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
scheme(lean1) ytitle("Predicted Similarity Score") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Spouse Race}", span)) ///
ylabel(.3(.05).7)  
graph save race_spouse_reg_S.gph, replace

grc1leg race_spouse_reg_N.gph race_spouse_reg_S.gph, altshrink scheme(lean1)
graph export figures3.eps, as(eps) preview(on) replace

**Appendix Figure S4. Neighborhood Context-Race Interactions on Neighbor and Similarity **
quietly reg neighborpair ib1.racet_a##ib1.neighborhood_a ib1.citizen_a ib0.identity_a ib1.language_a i.maritalstat_a_  ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racet_a, over(neighborhood_a)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
plot3opts(msymbol(Th) mcolor(blue)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
ci3opts(lcolor(blue)) ///
scheme(lean1) ytitle("Pr(Preferred Neighbor)") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Neighborhood Context}", span)) ///
ylabel(.3(.05).7) yline(.5, lpattern(dash))
graph save race_neighborhood_reg_N.gph, replace

quietly reg similar_a_ ib1.racet_a##ib1.neighborhood_a ib1.citizen_a ib0.identity_a ib1.language_a i.maritalstat_a_  ib0.volunteer_a ib0.workhist_a, vce(cluster respid)
margins racet_a, over(neighborhood_a)
marginsplot, recast(scatter) ///
plot1opts(msymbol(Sh) mcolor(red)) ///
plot2opts(msymbol(Oh) mcolor(green)) ///
plot3opts(msymbol(Th) mcolor(blue)) ///
ci1opts(lcolor(red)) ///
ci2opts(lcolor(green)) ///
ci3opts(lcolor(blue)) ///
scheme(lean1) ytitle("Predicted Similarity Score") xtitle("{it:Race Treatment}") title("") ///
legend(position(12) row(1) ring(0) subtitle("{it:Neighborhood Context}", span)) ///
ylabel(.3(.05).7)
graph save race_neighborhood_reg_S.gph, replace

grc1leg race_neighborhood_reg_N.gph race_neighborhood_reg_S.gph, altshrink scheme(lean1)
graph export figures4.eps, as(eps) preview(on) replace
